jQuery.scrollTo
Description: Demo of jQuery.scrollTo. Lightweight, cross-browser and highly customizable animated scrolling with jQuery, made by Ariel Flesler.
Keywords: javascript, jquery, plugins, scroll, scrollTo, smooth, animation, to, effect, ariel, flesler, window, overflow, element, navigation, customizable

# jQuery.scrollTo by Ariel Flesler

### Links

- Github
- Main blog article
- LocalScroll Demo
- SerialScroll Demo
- Old Demo

### Ways to specify the target Click an option, to see it in action

- Relative selector
- jQuery object
- DOM Element
- Absolute number
- Absolute number(hash)

- Absolute px
- Absolute px(hash)
- Relative px
- Relative px(hash)
- Percent
- Percent(hash)

- 0

  go back

- 1

  go back

- 2

  go back

- 3

  go back

- 4

  go back

- 5

  go back

- 6

  go back

- 7

  go back

- 8

  go back

- 9

  go back

- 10

  go back

- 11

  go back

- 12

  go back

- 13

  go back

- 14

  go back

- 15

  go back

- 16

  go back

- 17

  go back

- 18

  go back

- 19

  go back

- 20

  go back

- 21

  go back

- 22

  go back

- 23

  go back

- 24

  go back

- 25

  go back

- 26

  go back

- 27

  go back

- 28

  go back

- 29

  go back

### Settings The examples shown here, are summarized for brevity

- no settings
- axis
- margin
- offset
- offset(hash)
- offset(function)
- over
- over(hash)
- interrupt
- onAfter
- onAfterFirst

#### Settings inherited from $().animate()

- duration
- easing
- queue
- step
- progress
- fail
- more

- 0

  go back

- 1

  go back

- 2

  go back

- 3

  go back

- 4

  go back

- 5

  go back

- 6

  go back

- 7

  go back

- 8

  go back

- 9

  go back

- 10

  go back

- 11

  go back

- 12

  go back

- 13

  go back

- 14

  go back

- 15

  go back

- 16

  go back

- 17

  go back

- 18

  go back

- 19

  go back

- 20

  go back

- 21

  go back

- 22

  go back

- 23

  go back

- 24

  go back

- 25

  go back

- 26

  go back

- 27

  go back

- 28

  go back

- 29

  go back